Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1011)

Unified Diff: content/browser/fileapi/local_file_util_unittest.cc

Issue 89523002: Move Posix file utils to the base namespace. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/fileapi/dragged_file_util_unittest.cc ('k') | content/common/set_process_title.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/fileapi/local_file_util_unittest.cc
diff --git a/content/browser/fileapi/local_file_util_unittest.cc b/content/browser/fileapi/local_file_util_unittest.cc
index e4d2fb196053be88b2f6a29a86db76cf06945882..fd28035aafe3c1c26603024605baf7688dec38ae 100644
--- a/content/browser/fileapi/local_file_util_unittest.cc
+++ b/content/browser/fileapi/local_file_util_unittest.cc
@@ -138,7 +138,7 @@ TEST_F(LocalFileUtilTest, CreateAndClose) {
file_util()->Close(context.get(), file_handle));
}
// file_util::CreateSymbolicLink is only supported on POSIX.
#if defined(OS_POSIX)
TEST_F(LocalFileUtilTest, CreateFailForSymlink) {
// Create symlink target file.
@@ -153,7 +153,7 @@ TEST_F(LocalFileUtilTest, CreateFailForSymlink) {
// Create symlink where target must be real file.
const char *symlink_name = "symlink_file";
base::FilePath symlink_path = LocalPath(symlink_name);
- ASSERT_TRUE(file_util::CreateSymbolicLink(target_path, symlink_path));
+ ASSERT_TRUE(base::CreateSymbolicLink(target_path, symlink_path));
ASSERT_TRUE(FileExists(symlink_name));
// Try to open the symlink file which should fail.
« no previous file with comments | « content/browser/fileapi/dragged_file_util_unittest.cc ('k') | content/common/set_process_title.cc » ('j') | no next file with comments »
@@ -138,7 +138,7 @@ TEST_F(LocalFileUtilTest, CreateAndClose) {
file_util()->Close(context.get(), file_handle));
}
-// file_util::CreateSymbolicLink is only supported on POSIX.
+// base::CreateSymbolicLink is only supported on POSIX.
#if defined(OS_POSIX)
TEST_F(LocalFileUtilTest, CreateFailForSymlink) {

Powered by Google App Engine
This is Rietveld 408576698